.. Nekbot Doc documentation master file, created by
   sphinx-quickstart2 on Thu Apr 23 05:29:44 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentación de NekBot!
========================

Contents:

Desarrolladores
---------------

.. toctree::
   :maxdepth: 2

   first_steps

Indices y tablas
================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

